@@ -20,7 +20,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #if	defined (POSIX) || defined (HAVE_DIRENT_H) || defined (__GNU_LIBRARY__)
 #include <dirent.h>
-#ifndef	__GNU_LIBRARY__
+#ifndef	__BAD_GNU_LIBRARY__
 #define D_NAMLEN(d) strlen((d)->d_name)
 #else	/* GNU C library.  */
 #define D_NAMLEN(d) ((d)->d_namlen)
