@@ -1,5 +1,5 @@
 /* Implementation of pattern-matching file search paths for GNU Make.
-Copyright (C) 1988, 1989, 1991, 1992, 1993 Free Software Foundation, Inc.
+Copyright (C) 1988, 1989, 1991, 1992, 1993, 1994 Free Software Foundation, Inc.
 This file is part of GNU Make.
 
 GNU Make is free software; you can redistribute it and/or modify
@@ -177,7 +177,7 @@ construct_vpath_list (pattern, dirpath)
   maxelem = 2;
   p = dirpath;
   while (*p != '\0')
-    if (*p++ == ':' || isblank (*p))
+    if (*p++ == PATH_SEPARATOR_CHAR || isblank (*p))
       ++maxelem;
 
   vpath = (char **) xmalloc (maxelem * sizeof (char *));
@@ -185,7 +185,7 @@ construct_vpath_list (pattern, dirpath)
 
   /* Skip over any initial colons and blanks.  */
   p = dirpath;
-  while (*p == ':' || isblank (*p))
+  while (*p == PATH_SEPARATOR_CHAR || isblank (*p))
     ++p;
 
   elem = 0;
@@ -196,7 +196,7 @@ construct_vpath_list (pattern, dirpath)
 
       /* Find the end of this entry.  */
       v = p;
-      while (*p != '\0' && *p != ':' && !isblank (*p))
+      while (*p != '\0' && *p != PATH_SEPARATOR_CHAR && !isblank (*p))
 	++p;
 
       len = p - v;
@@ -225,7 +225,7 @@ construct_vpath_list (pattern, dirpath)
 	}
 
       /* Skip over colons and blanks between entries.  */
-      while (*p == ':' || isblank (*p))
+      while (*p == PATH_SEPARATOR_CHAR || isblank (*p))
 	++p;
     }
 
@@ -419,7 +419,7 @@ selective_vpath_search (path, file, mtime_ptr)
 	  *n = '/';
 
 	  if (!exists_in_cache	/* Makefile-mentioned file need not exist.  */
-	      || stat (name, &st) == 0)	/* Does it really exist?  */
+	      || safe_stat (name, &st) == 0) /* Does it really exist?  */
 	    {
 	      /* We have found a file.
 		 Store the name we found into *FILE for the caller.  */
@@ -434,6 +434,8 @@ selective_vpath_search (path, file, mtime_ptr)
 
 	      return 1;
 	    }
+	  else
+	    exists = 0;
 	}
     }
 
@@ -461,7 +463,7 @@ print_vpath_data_base ()
 
       for (i = 0; v->searchpath[i] != 0; ++i)
 	printf ("%s%c", v->searchpath[i],
-		v->searchpath[i + 1] == 0 ? '\n' : ':');
+		v->searchpath[i + 1] == 0 ? '\n' : PATH_SEPARATOR_CHAR);
     }
 
   if (vpaths == 0)
@@ -479,6 +481,7 @@ print_vpath_data_base ()
       fputs ("\n# General (`VPATH' variable) search path:\n# ", stdout);
 
       for (i = 0; path[i] != 0; ++i)
-	printf ("%s%c", path[i], path[i + 1] == 0 ? '\n' : ':');
+	printf ("%s%c", path[i],
+		path[i + 1] == 0 ? '\n' : PATH_SEPARATOR_CHAR);
     }
 }
